@@ -9,7 +9,7 @@ VOID s_cat(char *lp, char *rpp[], ftnlen rnp[], ftnlen *np, ftnlen ll)
 ftnlen i, n, nc;
 char *f__rp;
 
-n = (int)*np;
+n = *np;
 for(i = 0 ; i < n ; ++i)
 	{
 	nc = ll;
