@@ -1,4 +1,4 @@
-static char junk[] = "\n@(#) LIBI77 VERSION pjw,dmg-mods 12 July 1994\n";
+static char junk[] = "\n@(#) LIBI77 VERSION pjw,dmg-mods 2 Nov. 1994\n";
 
 /*
 2.01	$ format added
@@ -189,3 +189,13 @@ wrtfmt.c:
 		 Omit '.' in list-directed printing of Nan, Infinity. */
 /* 12 July 1994: wrtfmt.c: under G11.4, write 0. as "  .0000    " rather
 		 than "  .0000E+00". */
+/* 3 Aug. 1994:  lwrite.c: do not insert a newline when appending an
+		 oversize item to an empty line. */
+/* 12 Aug. 1994: rsli.c rsne.c: fix glitch (reset nml_read) that kept
+		 ERR= (in list- or format-directed input) from working
+		 after a NAMELIST READ. */
+/* 7 Sept. 1994: typesize.c: adjust to allow types LOGICAL*1, LOGICAL*2,
+		 INTEGER*1, and (under -DAllow_TYQUAD) INTEGER*8
+		 in NAMELISTs. */
+/* 6 Oct. 1994:  util.c: omit f__mvgbt, as it is never used. */
+/* 2 Nov. 1994:  add #ifdef ALWAYS_FLUSH logic */
